@@ -22,21 +22,28 @@ impl<'a, 'b> ClientCommand<'a, 'b> for SignDeploy {
             ))
             .arg(creation_common::input::arg())
             .arg(creation_common::output::arg())
+            .arg(common::force::arg(
+                creation_common::DisplayOrder::Force as usize,
+                true,
+            ))
     }
 
     fn run(matches: &ArgMatches<'_>) -> Result<Success, Error> {
         let input_path = creation_common::input::get(matches);
         let secret_key = common::secret_key::get(matches);
         let maybe_output_path = creation_common::output::get(matches).unwrap_or_default();
-        casper_client::sign_deploy_file(input_path, secret_key, maybe_output_path).map(|_| {
-            Success::Output(if maybe_output_path.is_empty() {
-                String::new()
-            } else {
-                format!(
-                    "Signed the deploy at {} and wrote to {}",
-                    input_path, maybe_output_path
-                )
-            })
-        })
+        let force = common::force::get(matches);
+        casper_client::sign_deploy_file(input_path, secret_key, maybe_output_path, force).map(
+            |_| {
+                Success::Output(if maybe_output_path.is_empty() {
+                    String::new()
+                } else {
+                    format!(
+                        "Signed the deploy at {} and wrote to {}",
+                        input_path, maybe_output_path
+                    )
+                })
+            },
+        )
     }
 }
