@@ -12,12 +12,13 @@ enum DisplayOrder {
     Verbose,
     NodeAddress,
     RpcId,
+    BlockIdentifier,
 }
 
 impl<'a, 'b> ClientCommand<'a, 'b> for GetAuctionInfo {
     const NAME: &'static str = "get-auction-info";
     const ABOUT: &'static str =
-        "Retrieves the bids and validators as of the most recently added block";
+        "Returns the bids and validators as of either a specific block (by height or hash), or the most recently added block";
 
     fn build(display_order: usize) -> App<'a, 'b> {
         SubCommand::with_name(Self::NAME)
@@ -28,14 +29,18 @@ impl<'a, 'b> ClientCommand<'a, 'b> for GetAuctionInfo {
                 DisplayOrder::NodeAddress as usize,
             ))
             .arg(common::rpc_id::arg(DisplayOrder::RpcId as usize))
+            .arg(common::block_identifier::arg(
+                DisplayOrder::BlockIdentifier as usize,
+            ))
     }
 
     fn run(matches: &ArgMatches<'_>) -> Result<Success, Error> {
         let maybe_rpc_id = common::rpc_id::get(matches);
         let node_address = common::node_address::get(matches);
         let verbosity_level = common::verbose::get(matches);
+        let maybe_block_id = common::block_identifier::get(matches);
 
-        casper_client::get_auction_info(maybe_rpc_id, node_address, verbosity_level)
+        casper_client::get_auction_info(maybe_rpc_id, node_address, verbosity_level, maybe_block_id)
             .map(Success::from)
     }
 }
